@@ -6,30 +6,17 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#ifndef GLOBALS_H
-#define GLOBALS_H
+#pragma once
 
+// Qt
+#include <QLatin1String>
+// Kaidan
 #include <GlobalsGen.h>
 
-#include <QLatin1String>
-
 // Kaidan settings
-#define KAIDAN_SETTINGS_AUTH_ONLINE "auth/online"
-#define KAIDAN_SETTINGS_AUTH_JID "auth/jid"
-#define KAIDAN_SETTINGS_AUTH_JID_RESOURCE_PREFIX "auth/jidResourcePrefix"
-#define KAIDAN_SETTINGS_AUTH_PASSWD "auth/password"
-#define KAIDAN_SETTINGS_AUTH_CREDENTIALS "auth/credentials"
-#define KAIDAN_SETTINGS_AUTH_HOST "auth/host"
-#define KAIDAN_SETTINGS_AUTH_PORT "auth/port"
-#define KAIDAN_SETTINGS_AUTH_TLS_ERRORS_IGNORED "auth/tlsErrorsIgnored"
-#define KAIDAN_SETTINGS_AUTH_TLS_REQUIREMENT "auth/tlsRequirement"
-#define KAIDAN_SETTINGS_AUTH_PASSWD_VISIBILITY "auth/passwordVisibility"
-#define KAIDAN_SETTINGS_AUTH_DEVICE_ID "auth/userAgentDeviceId"
-#define KAIDAN_SETTINGS_ENCRYPTION "encryption"
 #define KAIDAN_SETTINGS_FAVORITE_EMOJIS "emojis/favorites"
 #define KAIDAN_SETTINGS_WINDOW_POSITION "window/position"
 #define KAIDAN_SETTINGS_WINDOW_SIZE "window/size"
-#define KAIDAN_SETTINGS_AUTOMATIC_MEDIA_DOWNLOADS_RULE "media/automaticDownloadsRule"
 #define KAIDAN_SETTINGS_EXPLANATION_VISIBILITY_CONTACT_ADDITION_QR_CODE_PAGE "explanationVisibility/contactAdditionQrCodePage"
 #define KAIDAN_SETTINGS_EXPLANATION_VISIBILITY_KEY_AUTHENTICATION_PAGE "explanationVisibility/keyAuthenticationPage"
 
@@ -140,5 +127,3 @@ constexpr QStringView ENCRYPTION_KEY_ID_CHARACTER_GROUP_SEPARATOR = u" ";
 inline constexpr QStringView XMLNS_SFS = u"urn:xmpp:sfs:0";
 inline constexpr QStringView XMLNS_MESSAGE_REPLIES = u"urn:xmpp:reply:0";
 const auto XMLNS_OMEMO_2 = QStringLiteral("urn:xmpp:omemo:2");
-
-#endif // GLOBALS_H
