@@ -8,11 +8,10 @@
 
 #include "Notifications.h"
 
-// KNotifications
+// KDE
 #ifdef HAVE_KNOTIFICATIONS
 #include <KNotification>
 #endif
-
 // Kaidan
 #include "ChatController.h"
 #include "Kaidan.h"
@@ -20,11 +19,9 @@
 #include "RosterDb.h"
 #include "RosterModel.h"
 
-#include <QStringBuilder>
-
-// Q_OS_BSD4 includes all BSD variants and also Q_OS_DARWIN
+// Q_OS_BSD4 includes all BSD variants and also Q_OS_APPLE
 // Q_OS_LINUX is also defined on Android
-#if (defined(Q_OS_LINUX) || defined(Q_OS_BSD4) || defined(Q_OS_HURD)) && !defined(Q_OS_ANDROID) && !defined(Q_OS_DARWIN)
+#if (defined(Q_OS_LINUX) || defined(Q_OS_BSD4) || defined(Q_OS_HURD)) && !defined(Q_OS_ANDROID) && !defined(Q_OS_APPLE)
 #define DESKTOP_LINUX_ALIKE_OS
 #endif
 
